@@ -33,7 +33,7 @@ from pyof.foundation.exceptions import (
 
 # This will determine the order on sphinx documentation.
 __all__ = ('GenericStruct', 'GenericMessage', 'GenericType', 'GenericBitMask',
-           'MetaStruct', 'MetaBitMask')
+           'MetaStruct', 'MetaBitMask', 'UBIntBase')
 
 # Classes
 
@@ -41,7 +41,7 @@ __all__ = ('GenericStruct', 'GenericMessage', 'GenericType', 'GenericBitMask',
 class GenericType:
     """Foundation class for all custom attributes.
 
-    Base class for :class:`~.UBInt8`, :class:`~.Char`
+    Base class for :class:`~.UBIntBase`, :class:`~.Char`
     and others.
     """
 
@@ -63,7 +63,7 @@ class GenericType:
         return type(self)(value=self._value, enum_ref=self.enum_ref)
 
     def __repr__(self):
-        return "{}({})".format(type(self).__name__, self._value)
+        return "{}({})".format(type(self).__name__, repr(self._value))
 
     def __str__(self):
         return '{}'.format(str(self._value))
@@ -71,7 +71,7 @@ class GenericType:
     def __eq__(self, other):
         if isinstance(other, self.__class__):
             return self.pack() == other.pack()
-        elif hasattr(other, 'value'):
+        if hasattr(other, 'value'):
             return self.value == other.value
         return self.value == other
 
@@ -137,14 +137,13 @@ class GenericType:
             object: The value of an enum, bitmask, etc.
 
         """
-        if self.isenum():
+        if self.is_enum():
             if isinstance(self._value, self.enum_ref):
                 return self._value.value
             return self._value
-        elif self.is_bitmask():
+        if self.is_bitmask():
             return self._value.bitmask
-        else:
-            return self._value
+        return self._value
 
     def pack(self, value=None):
         r"""Pack the value as a binary representation.
@@ -241,7 +240,7 @@ class GenericType:
         except BadValueException:
             return False
 
-    def isenum(self):
+    def is_enum(self):
         """Test whether it is an :class:`~enum.Enum`.
 
         Returns:
@@ -260,8 +259,18 @@ class GenericType:
         return self._value and issubclass(type(self._value), GenericBitMask)
 
 
+class UBIntBase(GenericType):
+    """Base class for UBInt{8,16,32,64,128}."""
+
+    def __int__(self):
+        """Allow converting an UBInt() back to an int()."""
+        # Skip GenericType's checking if this is an Enum ou BitMask
+        # (because it won't be), and convert directly from _value
+        return int(self._value)
+
+
 class MetaStruct(type):
-    """MetaClass that dinamically handles openflow version of class attributes.
+    """MetaClass that dynamically handles openflow version of class attributes.
 
     See more about it at:
         https://github.com/kytos/python-openflow/wiki/Version-Inheritance
@@ -272,10 +281,10 @@ class MetaStruct(type):
 
     # pylint: disable=unused-argument
     @classmethod
-    def __prepare__(mcs, name, bases, **kwargs):
+    def __prepare__(cls, name, bases, **kwargs):
         return OrderedDict()
 
-    def __new__(mcs, name, bases, classdict, **kwargs):
+    def __new__(cls, name, bases, classdict, **kwargs):
         """Inherit attributes from parent class and update their versions.
 
         Here is the moment that the new class is going to be created. During
@@ -321,7 +330,7 @@ class MetaStruct(type):
                                                                curr_version)
 
                     if attr_name == 'header':
-                        attr = mcs._header_message_type_update(obj, attr)
+                        attr = cls._header_message_type_update(obj, attr)
 
                     inherited_attributes.update([attr])
                 #: We are going to inherit just from the 'closest parent'
@@ -341,7 +350,7 @@ class MetaStruct(type):
             inherited_attributes.update(classdict)
             classdict = inherited_attributes
 
-        return super().__new__(mcs, name, bases, classdict, **kwargs)
+        return super().__new__(cls, name, bases, classdict, **kwargs)
 
     @staticmethod
     def _header_message_type_update(obj, attr):
@@ -425,7 +434,6 @@ class MetaStruct(type):
         an instance of the new version of the 'obj'.
 
         Example:
-
         >>> from pyof.foundation.base import MetaStruct as ms
         >>> from pyof.v0x01.common.header import Header
         >>> name = 'header'
@@ -478,7 +486,7 @@ class MetaStruct(type):
         return (name, obj)
 
 
-class GenericStruct(object, metaclass=MetaStruct):
+class GenericStruct(metaclass=MetaStruct):
     """Class inherited by all OpenFlow structs.
 
     If you need to insert a method that will be used by all structs, this is
@@ -490,7 +498,7 @@ class GenericStruct(object, metaclass=MetaStruct):
     """
 
     def __init__(self):
-        """Contructor takes no argument and stores attributes' deep copies."""
+        """Store attributes' deep copies."""
         for name, value in self.get_class_attributes():
             setattr(self, name, deepcopy(value))
 
@@ -504,11 +512,24 @@ class GenericStruct(object, metaclass=MetaStruct):
             other (GenericStruct): The struct to be compared with.
 
         Returns:
-            bool: Returns the result of comparation.
+            bool: Returns the comparison result.
 
         """
         return self.pack() == other.pack()
 
+    # def __repr__(self):
+    #     """Generic fallback for __repr__ using the built-in introspection.
+    #
+    #     For debugging purposes. Disabled to avoid infinite recursion in
+    #     the case that objects reference each other.
+    #
+    #     """
+    #     # from pprint import pformat
+    #     # attributes = pformat(dict(self._get_instance_attributes()))
+    #     attributes = ', '.join(f'{k}={v!r}' for (k, v)
+    #                            in self._get_instance_attributes())
+    #     return f'{type(self).__name__}({attributes})'
+
     @staticmethod
     def _attr_fits_into_class(attr, cls):
         if not isinstance(attr, cls):
@@ -520,13 +541,13 @@ class GenericStruct(object, metaclass=MetaStruct):
 
     @staticmethod
     def _is_pyof_attribute(obj):
-        """Return True if the object is a kytos attribute.
+        """Return True if the object is a pyof attribute.
 
-        To be a kytos attribute the item must be an instance of either
+        To be a pyof attribute the item must be an instance of either
         GenericType or GenericStruct.
 
         Returns:
-            bool: Returns TRUE if the obj is a kytos attribute, otherwise False
+            bool: Returns True if the obj is a pyof attribute, otherwise False
 
         """
         return isinstance(obj, (GenericType, GenericStruct))
@@ -536,7 +557,7 @@ class GenericStruct(object, metaclass=MetaStruct):
         for _attr, _class in self._get_attributes():
             if isinstance(_attr, _class):
                 return True
-            elif issubclass(_class, GenericType):
+            if issubclass(_class, GenericType):
                 if GenericStruct._attr_fits_into_class(_attr, _class):
                     return True
             elif not isinstance(_attr, _class):
@@ -549,7 +570,7 @@ class GenericStruct(object, metaclass=MetaStruct):
 
         This method strict relies on the PEP 520 (Preserving Class Attribute
         Definition Order), implemented on Python 3.6. So, if this behaviour
-        changes this whole lib can loose its functionality (since the
+        changes this whole lib can lose its functionality (since the
         attributes order are a strong requirement.) For the same reason, this
         lib will not work on python versions earlier than 3.6.
 
@@ -566,7 +587,7 @@ class GenericStruct(object, metaclass=MetaStruct):
         #: see this method docstring for a important notice about the use of
         #: cls.__dict__
         for name, value in cls.__dict__.items():
-            # gets only our (kytos) attributes. this ignores methods, dunder
+            # gets only our (pyof) attributes. this ignores methods, dunder
             # methods and attributes, and common python type attributes.
             if GenericStruct._is_pyof_attribute(value):
                 yield (name, value)
@@ -656,12 +677,10 @@ class GenericStruct(object, metaclass=MetaStruct):
         if value is None:
             return sum(cls_val.get_size(obj_val) for obj_val, cls_val in
                        self._get_attributes())
-        elif isinstance(value, type(self)):
+        if isinstance(value, type(self)):
             return value.get_size()
-        else:
-            msg = "{} is not an instance of {}".format(value,
-                                                       type(self).__name__)
-            raise PackException(msg)
+        msg = "{} is not an instance of {}".format(value, type(self).__name__)
+        raise PackException(msg)
 
     def pack(self, value=None):
         """Pack the struct in a binary representation.
@@ -682,24 +701,21 @@ class GenericStruct(object, metaclass=MetaStruct):
                 error_msg = "Error on validation prior to pack() on class "
                 error_msg += "{}.".format(type(self).__name__)
                 raise ValidationError(error_msg)
-            else:
-                message = b''
-                # pylint: disable=no-member
-                for attr_info in self._get_named_attributes():
-                    name, instance_value, class_value = attr_info
-                    try:
-                        message += class_value.pack(instance_value)
-                    except PackException as pack_exception:
-                        cls = type(self).__name__
-                        msg = f'{cls}.{name} - {pack_exception}'
-                        raise PackException(msg)
-                return message
-        elif isinstance(value, type(self)):
+            message = b''
+            # pylint: disable=no-member
+            for attr_info in self._get_named_attributes():
+                name, instance_value, class_value = attr_info
+                try:
+                    message += class_value.pack(instance_value)
+                except PackException as pack_exception:
+                    cls = type(self).__name__
+                    msg = f'{cls}.{name} - {pack_exception}'
+                    raise PackException(msg)
+            return message
+        if isinstance(value, type(self)):
             return value.pack()
-        else:
-            msg = "{} is not an instance of {}".format(value,
-                                                       type(self).__name__)
-            raise PackException(msg)
+        msg = "{} is not an instance of {}".format(value, type(self).__name__)
+        raise PackException(msg)
 
     def unpack(self, buff, offset=0):
         """Unpack a binary struct into this object's attributes.
@@ -804,12 +820,10 @@ class GenericMessage(GenericStruct):
         if value is None:
             self.update_header_length()
             return super().pack()
-        elif isinstance(value, type(self)):
+        if isinstance(value, type(self)):
             return value.pack()
-        else:
-            msg = "{} is not an instance of {}".format(value,
-                                                       type(self).__name__)
-            raise PackException(msg)
+        msg = "{} is not an instance of {}".format(value, type(self).__name__)
+        raise PackException(msg)
 
     def unpack(self, buff, offset=0):
         """Unpack a binary message into this object's attributes.
@@ -850,7 +864,7 @@ class MetaBitMask(type):
     access object.ELEMENT and recover either values or names).
     """
 
-    def __new__(mcs, name, bases, classdict):
+    def __new__(cls, name, bases, classdict):
         """Convert class attributes into enum elements."""
         _enum = OrderedDict([(key, value) for key, value in classdict.items()
                              if key[0] != '_' and not
@@ -861,7 +875,7 @@ class MetaBitMask(type):
                          if key[0] == '_' or hasattr(value, '__call__') or
                          isinstance(value, property)}
             classdict['_enum'] = _enum
-        return type.__new__(mcs, name, bases, classdict)
+        return type.__new__(cls, name, bases, classdict)
 
     def __getattr__(cls, name):
         return cls._enum[name]
@@ -873,7 +887,7 @@ class MetaBitMask(type):
         return res
 
 
-class GenericBitMask(object, metaclass=MetaBitMask):
+class GenericBitMask(metaclass=MetaBitMask):
     """Base class for enums that use bitmask values."""
 
     def __init__(self, bitmask=None):
