@@ -6,13 +6,11 @@ from copy import deepcopy
 
 # Local source tree imports
 from pyof.foundation import exceptions
-from pyof.foundation.base import GenericStruct, GenericType
-
-# Third-party imports
+from pyof.foundation.base import GenericStruct, GenericType, UBIntBase
 
 __all__ = ('BinaryData', 'Char', 'ConstantTypeList', 'FixedTypeList',
            'IPAddress', 'DPID', 'HWAddress', 'Pad', 'UBInt8', 'UBInt16',
-           'UBInt32', 'UBInt64')
+           'UBInt32', 'UBInt64', 'UBInt128')
 
 
 class Pad(GenericType):
@@ -59,7 +57,6 @@ class Pad(GenericType):
             buff: Buffer where data is located.
             offset (int): Where data stream begins.
         """
-        pass
 
     def pack(self, value=None):
         """Pack the object.
@@ -80,7 +77,7 @@ class Pad(GenericType):
         return Pad(length=self._length)
 
 
-class UBInt8(GenericType):
+class UBInt8(UBIntBase):
     """Format character for an Unsigned Char.
 
     Class for an 8-bit (1-byte) Unsigned Integer.
@@ -89,7 +86,7 @@ class UBInt8(GenericType):
     _fmt = "!B"
 
 
-class UBInt16(GenericType):
+class UBInt16(UBIntBase):
     """Format character for an Unsigned Short.
 
     Class for an 16-bit (2-byte) Unsigned Integer.
@@ -98,7 +95,7 @@ class UBInt16(GenericType):
     _fmt = "!H"
 
 
-class UBInt32(GenericType):
+class UBInt32(UBIntBase):
     """Format character for an Unsigned Int.
 
     Class for an 32-bit (4-byte) Unsigned Integer.
@@ -107,7 +104,7 @@ class UBInt32(GenericType):
     _fmt = "!I"
 
 
-class UBInt64(GenericType):
+class UBInt64(UBIntBase):
     """Format character for an Unsigned Long Long.
 
     Class for an 64-bit (8-byte) Unsigned Integer.
@@ -116,6 +113,15 @@ class UBInt64(GenericType):
     _fmt = "!Q"
 
 
+class UBInt128(UBIntBase):
+    """Format character for an Unsigned Long Long.
+
+    Class for an 128-bit (16-byte) Unsigned Integer.
+    """
+
+    _fmt = "!8H"
+
+
 class DPID(GenericType):
     """DataPath ID. Identifies a switch."""
 
@@ -344,6 +350,114 @@ class IPAddress(GenericType):
         return IPAddress(address=self._value, netmask=self.netmask)
 
 
+class IPv6Address(GenericType):
+    """Defines a IPv6 address."""
+
+    netmask = UBInt128()
+
+    def __init__(self, address="0000:0000:0000:0000:0000:0000:0000:0000/128",
+                 netmask=None):
+        """Create an IPv6Address with the parameters below.
+
+        Args:
+            address (str): IP Address using IPv6.
+            Defaults to '0000:0000:0000:0000:0000:0000:0000:0000/128'
+        """
+        if '/' in address:
+            address, netmask = address.split('/')
+        else:
+            netmask = 128 if netmask is None else netmask
+
+        if address == '::':
+            address = '0:0:0:0:0:0:0:0'
+        elif '::' in address:
+            temp = address.split(':')
+            index = temp.index('')
+            temp = [x for x in temp if x != '']
+            address = temp[:index] + ['0'] * (8 - len(temp)) + temp[index:]
+            address = ':'.join(address)
+
+        super().__init__(address)
+        self.netmask = int(netmask)
+
+    def pack(self, value=None):
+        """Pack the value as a binary representation.
+
+        If the value is None the self._value will be used to pack.
+
+        Args:
+            value (str): IP Address with IPv6 format.
+
+        Returns:
+            bytes: The binary representation.
+
+        Raises:
+            struct.error: If the value does not fit the binary format.
+
+        """
+        if isinstance(value, type(self)):
+            return value.pack()
+
+        if value is None:
+            value = self._value
+
+        if value.find('/') >= 0:
+            value = value.split('/')[0]
+
+        try:
+            value = value.split(':')
+            return struct.pack('!8H', *[int(x, 16) for x in value])
+        except struct.error as err:
+            msg = "IPv6Address error. "
+            msg += "Class: {}, struct error: {} ".format(type(value).__name__,
+                                                         err)
+            raise exceptions.PackException(msg)
+
+    def unpack(self, buff, offset=0):
+        """Unpack a binary message into this object's attributes.
+
+        Unpack the binary value *buff* and update this object attributes based
+        on the results.
+
+        Args:
+            buff (bytes): Binary data package to be unpacked.
+            offset (int): Where to begin unpacking.
+
+        Raises:
+            Exception: If there is a struct unpacking error.
+
+        """
+        def _int2hex(number):
+            return "{0:0{1}x}".format(number, 4)
+
+        try:
+            unpacked_data = struct.unpack('!8H', buff[offset:offset+16])
+        except struct.error as exception:
+            raise exceptions.UnpackException('%s; %s: %s' % (exception,
+                                                             offset, buff))
+
+        transformed_data = ':'.join([_int2hex(x) for x in unpacked_data])
+        self._value = transformed_data
+
+    def get_size(self, value=None):
+        """Return the IPv6 address size in bytes.
+
+        Args:
+            value: In structs, the user can assign other value instead of
+                this class' instance. Here, in such cases, ``self`` is a class
+                attribute of the struct.
+
+        Returns:
+            int: The address size in bytes.
+
+        """
+        return 16
+
+    def __deepcopy__(self, memo):
+        """Improve deepcopy speed."""
+        return IPv6Address(address=self._value, netmask=self.netmask)
+
+
 class HWAddress(GenericType):
     """Defines a hardware address."""
 
@@ -472,12 +586,11 @@ class BinaryData(GenericType):
 
         if hasattr(value, 'pack') and callable(value.pack):
             return value.pack()
-        elif isinstance(value, bytes):
+        if isinstance(value, bytes):
             return value
-        elif value is None:
+        if value is None:
             return b''
-        else:
-            raise ValueError(f"BinaryData can't be {type(value)} = '{value}'")
+        raise ValueError(f"BinaryData can't be {type(value)} = '{value}'")
 
     def unpack(self, buff, offset=0):
         """Unpack a binary message into this object's attributes.
@@ -606,7 +719,7 @@ class TypeList(list, GenericStruct):
             if not self:
                 # If this is a empty list, then returns zero
                 return 0
-            elif issubclass(type(self[0]), GenericType):
+            if issubclass(type(self[0]), GenericType):
                 # If the type of the elements is GenericType, then returns the
                 # length of the list multiplied by the size of the GenericType.
                 return len(self) * self[0].get_size()
