@@ -92,13 +92,14 @@ class TableFeaturePropType(IntEnum):
     # Experimenter for table-miss.
     OFPTFPT_EXPERIMENTER_MISS = 0xFFFF
 
+    # pylint: disable=comparison-with-callable
     def find_class(self):
         """Return a class related with this type."""
         if self.value <= 1:
             return InstructionsProperty
-        elif self.value <= 3:
+        if self.value <= 3:
             return NextTablesProperty
-        elif self.value <= 7:
+        if self.value <= 7:
             return ActionsProperty
 
         return OxmProperty
@@ -223,6 +224,9 @@ class Bucket(GenericStruct):
         self.watch_group = watch_group
         self.actions = actions
 
+    def __repr__(self):
+        return f"{type(self).__name__}(actions={self.actions!r})"
+
     def unpack(self, buff, offset=0):
         """Unpack bucket.
 
@@ -608,7 +612,7 @@ class ListOfProperty(FixedTypeList):
 
 
 class TableFeatures(GenericStruct):
-    """Abstration of common class Table Features.
+    """Abstraction of common class Table Features.
 
     Body for MultipartRequest of type OFPMP_TABLE_FEATURES.
     Body of reply to OFPMP_TABLE_FEATURES request.
